@@ -52,8 +52,8 @@ public:
 
     void loadModels();
     QList< QChar::Script > findRuns(const QString &text);
-    QList<QString> createOrderedModel(const QString &content);
-    int distance(const QList<QString> &model, const QHash<QString, int> &knownModel);
+    QVector<QString> createOrderedModel(const QString &content);
+    int distance(const QVector<QString> &model, const QHash<QString, int> &knownModel);
     QStringList guessFromTrigrams(const QString &sample, const QStringList &langs);
     QStringList identify(const QString &sample, const QList< QChar::Script > &scripts);
     QString guessFromDictionaries(const QString &sentence, const QStringList &candidates);
@@ -92,7 +92,8 @@ GuessLanguagePrivate::GuessLanguagePrivate()
         return;
     }
 
-    s_knownDictionaries = Loader::openLoader()->languages().toSet();
+    const QStringList languages = Loader::openLoader()->languages();
+    s_knownDictionaries = QSet<QString>(languages.begin(), languages.end());
     QSet<QString> dictionaryLanguages;
     for (const QString &dictName : qAsConst(s_knownDictionaries)) {
         QString languageName = QLocale(dictName).name();
@@ -498,7 +499,7 @@ GuessLanguagePrivate::GuessLanguagePrivate()
             qCDebug(SONNET_LOG_CORE) << "Unhandled script" << script;
             break;
         }
-        allLanguages.unite(names.toSet());
+        allLanguages.unite(QSet<QString>(names.constBegin(), names.constEnd()));
 
         { // Remove unknown languages
             QStringList pruned;
@@ -524,14 +525,15 @@ GuessLanguagePrivate::GuessLanguagePrivate()
     if (!allLanguages.contains(s_knownDictionaries)) {
         QSet<QString> dicts(s_knownDictionaries);
         dicts.subtract(allLanguages);
-        for (const QString &dictName : dicts) {
+        for (const QString &dictName : qAsConst(dicts)) {
             QString languageName = QLocale(dictName).name();
             if (languageName.isEmpty()) {
                 qCWarning(SONNET_LOG_CORE) << "Unable to parse language name" << dictName;
                 continue;
             }
             s_dictionaryNameMap[languageName] = dictName;
-            if (!s_scriptLanguages.values().contains(languageName)) {
+            if (std::find(s_scriptLanguages.cbegin(), s_scriptLanguages.cend(), languageName)
+                    == s_scriptLanguages.cend()) {
                 qCWarning(SONNET_LOG_CORE) << "Unable to handle language from dictionary"
                                            << dictName << languageName;
             }
@@ -568,7 +570,18 @@ QString GuessLanguage::identify(const QString &text, const QStringList &suggesti
         d->loadModels();
     }
 
-    QStringList candidateLanguages = d->identify(text, d->findRuns(text));
+    const QList<QChar::Script> scriptsList = d->findRuns(text);
+
+    QStringList candidateLanguages = d->identify(text, scriptsList);
+
+    //if guessing from trigrams fail
+    for (const QChar::Script script : scriptsList) {
+        const auto languagesList = d->s_scriptLanguages.values(script);
+        for (const QString &lang : languagesList) {
+            if (!d->s_knownModels.contains(lang))
+                candidateLanguages.append(lang);
+        }
+    }
 
     // Hack for some bad dictionary names
     for (int i = 0; i < candidateLanguages.count(); i++) {
@@ -597,7 +610,7 @@ QString GuessLanguage::identify(const QString &text, const QStringList &suggesti
         return suggestionsList.first();
     }
 
-    qCWarning(SONNET_LOG_CORE) << "Unable to find any suggestion for" << text;
+    qCDebug(SONNET_LOG_CORE) << "Unable to find any suggestion for" << text;
 
     // Not even any suggestions, give up
     return QString();
@@ -637,10 +650,10 @@ void GuessLanguagePrivate::loadModels()
         }
         availableLanguages.insert(iterator.key());
     }
-    QSet<QString> knownLanguages(s_scriptLanguages.values().toSet());
+    QSet<QString> knownLanguages(s_scriptLanguages.constBegin(), s_scriptLanguages.constEnd());
     knownLanguages.subtract(availableLanguages);
     if (!knownLanguages.isEmpty()) {
-        qCWarning(SONNET_LOG_CORE) << "Missing trigrams for languages:" << knownLanguages;
+        qCDebug(SONNET_LOG_CORE) << "Missing trigrams for languages:" << knownLanguages;
     }
 }
 
@@ -705,7 +718,7 @@ QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample,
 {
     QStringList ret;
 
-    const QList<QString> sampleTrigrams = createOrderedModel(sample);
+    const QVector<QString> sampleTrigrams = createOrderedModel(sample);
 
     // Sort by score
     QMultiMap<int, QString> scores;
@@ -744,29 +757,49 @@ QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample,
     return ret;
 }
 
-QList<QString> GuessLanguagePrivate::createOrderedModel(const QString &content)
+QVector<QString> GuessLanguagePrivate::createOrderedModel(const QString &content)
 {
     QHash<QString, int> trigramCounts;
-    QMap<int, QString> orderedTrigrams;
 
+    //collect trigrams
+    trigramCounts.reserve(content.size() - 2);
     for (int i = 0; i < (content.size() - 2); ++i) {
         QString tri = content.mid(i, 3).toLower();
         trigramCounts[tri]++;
     }
 
-    for (const QString &key : trigramCounts.keys()) {
-        const QChar *data = key.constData();
+    //invert the map <freq, trigram>
+    QVector<QPair<int, QString>> trigramFrequencyList;
+    trigramFrequencyList.reserve(trigramCounts.size());
+
+    auto it = trigramCounts.constBegin();
+    for (; it != trigramCounts.constEnd(); ++it) {
+        const QChar *data = it.key().constData();
         bool hasTwoSpaces = (data[1].isSpace() && (data[0].isSpace() || data[2].isSpace()));
 
         if (!hasTwoSpaces) {
-            orderedTrigrams.insertMulti(-trigramCounts[key], key);
+            const int freq = it.value();
+            const QString& trigram = it.key();
+            trigramFrequencyList.append({freq, trigram});
         }
     }
 
-    return orderedTrigrams.values();
+    //sort descending by frequency
+    std::sort(trigramFrequencyList.begin(), trigramFrequencyList.end(), [](const QPair<int, QString>& a, const QPair<int, QString>& b) {
+        return a.first > b.first;
+    });
+
+
+    QVector<QString> orderedTrigrams;
+    orderedTrigrams.reserve(trigramFrequencyList.size());
+    for (const auto& tri : qAsConst(trigramFrequencyList)) {
+        orderedTrigrams.append(tri.second);
+    }
+
+    return orderedTrigrams;
 }
 
-int GuessLanguagePrivate::distance(const QList<QString> &model, const QHash<QString,
+int GuessLanguagePrivate::distance(const QVector<QString> &model, const QHash<QString,
                                                                             int> &knownModel)
 {
     int counter = -1;
