@@ -1,31 +1,18 @@
 /*
  * configdialog.h
  *
- * Copyright (C)  2004  Zack Rusin <zack@kde.org>
+ * SPDX-FileCopyrightText: 2004 Zack Rusin <zack@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #ifndef SONNET_CONFIGDIALOG_H
 #define SONNET_CONFIGDIALOG_H
 
 #include <QDialog>
-#include <sonnet/sonnetui_export.h>
+class ConfigDialogPrivate;
+#include "sonnetui_export.h"
 
-namespace Sonnet
-{
+namespace Sonnet {
 /// The sonnet ConfigDialog
 class SONNETUI_EXPORT ConfigDialog : public QDialog
 {
@@ -71,9 +58,7 @@ Q_SIGNALS:
     void configChanged();
 
 private:
-    class Private;
-    friend class Private;
-    Private *const d;
+    ConfigDialogPrivate *const d;
     Q_DISABLE_COPY(ConfigDialog)
     Q_PRIVATE_SLOT(d, void slotConfigChanged())
 };
